#if !defined HATP_WORLDBASE_UPDATER_HH_
#define HATP_WORLDBASE_UPDATER_HH_

#include <list>
#include <vector>
#include <set>
#include <map>
#include <string>
#include <sstream>

#include "msgClient.hh"
#include "WorldBase.hh"
#include "Entity.hh"

/**This class is responsible of updating the initial state, for the planning, from an ontology
 */
class WorldBaseUpdater{
private:
	/** Message client used to give error message to the console */
	msgClient& mp;
	/** Name of the ontology client to talk to */
	std::string ontology_client;
	/** Name of the hatpconsole to send to */
	std::string console_name;
	/** Verbosity level */
	unsigned short VERBOSE_LEVEL;

	WorldBaseUpdater();
	WorldBaseUpdater(WorldBaseUpdater&);
	WorldBaseUpdater& operator=(WorldBaseUpdater&);

	std::vector<std::string> getUpdatedProperty(const std::string& agent, const std::string& object, const std::string& property);

public:
	/** Constructor
	 * Only way to construct this object
	 * @param mp The message client to use
	 * @param ontology_client The client to communicate with
	 * @param console_name The console to send message to
	 * @param VERBOSE_LEVEL The verbosity level
	 */
	WorldBaseUpdater(msgClient& mp, const std::string& ontology_client, const std::string& console_name, unsigned short VERBOSE_LEVEL):
		mp(mp), ontology_client(ontology_client), console_name(console_name), VERBOSE_LEVEL(VERBOSE_LEVEL)
	{};
	
	bool updateWholeBMWorldBaseFromOntology(WorldBase& base);
	bool updateWholeWorldBaseFromOntology(WorldBase& base);
	
	//For retro-compatibility
	bool updateBMWorldBaseFromOntology(WorldBase& base);
	bool updateWorldBaseFromOntology(WorldBase& base);
};

#endif
